# include Interface
source mcPolymerInterface.tcl
# include Hamielec model
source Hamielec.tcl

# define low molecular species
Monomer Styrene
Species I#
Species R#

# special nitroxide
Species N#
Species RN

# define macromolecules
SpeciesMacro P#
SpeciesMacroD D

# special nitroxide
SpeciesMacro PN

# set initial concentrations
Concentration Styrene 8.725
Concentration RN 0.02

# debug function
ListAllSpecies  

# define reaction rate constants

# arrhenius A EA/R 
RateConstantArrhenius kp 4.265800e+07 3.910000e+03
RateConstantArrhenius km 2.31e+6 6.377e+3
RateConstantArrhenius kt 2.120000e+09 7.530000e+02
RateConstantArrhenius kth 2.200000e+05 1.381000e+04

# special N-Oxyle
# BIPNO:
RateConstant kd 6.8e-3
RateConstant kc 6.32e5

# debug function
ListAllRateConstants


# define reactions 

# styrene polymerization
ThermalInitiation Styrene + Styrene + Styrene --> P# + P# kth 
Propagation P# + Styrene --> P# kp 
Termination P# + P# --> D kt
Transfer2monomer P# + Styrene --> D + P# km

# special nitroxide
Elemental_1E2P RN --> R# + N# kd
Elemental_2E1P R# + N# --> RN kc
Initiation R# + Styrene --> P# kp
Transfer_PL-P P# + N# --> PN kc
Transfer_P-PL PN --> P# + N# kd

# debug function
ListAllReactions

# set reaction temperature 
Temperature 123.0

# set frequency for writing intermediate results 
# and update rate coefficients by the Hamielec model
Setdt 60.0

# set mode of storage: vector
SetCalculateMacromolecules on

# activate Hamielec model
SetUseHamielecModel on

# define number of molecules for simulation 1e8..1e11
InitSimulation 1e10

# start simulation to overall reaction time
Simulation 3600 
