# include Interface
source mcPolymerInterface.tcl

# define low molecular species
Monomer MA
Initiator AIBN 0.64 
Species I#

# define macromolecules
SpeciesMacro P#
SpeciesMacroD D

# special RAFT Polymerization

Species RS-C=S
Species R#

SpeciesMacroD RS-CP-SP
SpeciesMacro PS-C=S
SpeciesMacro RS-C#-SP
SpeciesMacro_P-O-P PS-C#-SP
SpeciesMacro_P-O<PP PS-CP-SP

Concentration MA 11.04
Concentration AIBN 0.01
Concentration RS-C=S 2.5e-02

# debug function
ListAllSpecies  

# reaction coefficients
RateConstantArrhenius kiAIBN 2.89e15 1.5663e+04
RateConstantArrhenius kp 3.61e6 1.671e3
RateConstantArrhenius kt 1.59e10 1.082e+3

set f_kt 0.15
set ka_kt [expr 1.59e10 * $f_kt]
RateConstantArrhenius kt_red $ka_kt 1.082e+3
RateConstant kadd 9.36e+06
RateConstant kfrac 7.84e+02
RateConstant kadd_start 3.06e+08
RateConstant kfrac_start 2.09e+01

# debug function
ListAllRateConstants

# reactions 

# MA polymerization
InitiatorDecomposition AIBN --> I# + I# kiAIBN 
Propagation P# + MA --> P# kp 
Termination P# + P# --> D kt
Initiation I# + MA --> P# kp

# special RAFT

#pre Equilibrium
Transfer_PL-P P# + RS-C=S --> RS-C#-SP kadd_start
Transfer_P-PL RS-C#-SP --> PS-C=S + R# kfrac_start
Initiation R# + MA --> P# kp
Transfer_PL-P PS-C=S + R# --> RS-C#-SP kadd_start
Transfer_P-PL RS-C#-SP --> P# + RS-C=S kfrac_start

#main Equilibrium
ChainAddition P# + PS-C=S --> PS-C#-SP kadd
ChainFragmentation PS-C#-SP --> PS-C=S + P# kfrac

# cross termination
Termination P# + RS-C#-SP --> RS-CP-SP kt_red
ChainAddition P# + PS-C#-SP --> PS-CP-SP kt_red

puts "call listReactions"
# Interface function
ListAllReactions

# temperature steps
Temperature 80.0

# set frequency for writing intermediate results 
Setdt 60.0
SetCalculateMacromolecules on

# define number of molecules for simulation 1e8..1e10
InitSimulation 1e10

# start simulation to overall reaction time
Simulation 3600
